@@ -44,7 +44,7 @@ def generate_actions_from_irc_message(args,printer):
         printer("Monitoring channel" + channel, str(monitoring_channel))
 
     if debug:
-        printer("to_me: " + str(to_me) + ", from_me: " + str(from_me) + ", monitoring_channel: " + str(monitoring_channel),"")
+        printer("", "to_me: " + str(to_me) + ", from_me: " + str(from_me) + ", monitoring_channel: " + str(monitoring_channel))
 
     if not to_me and not from_me and monitoring_channel:
         elapsed_time = get_elapsed_time_on_channel(channel, monitored_channels)
@@ -142,10 +142,10 @@ def monitored_channel(channel, monitored_channels):
 
 
 def construct_alert(frm, channel, msg, elapsed=None):
-    alert_title = frm + u"@" + channel + u":"
+    alert_title = frm + "@" + channel + ":"
     message = msg
     if elapsed:
-        message += u" (" + unicode(round(seconds_listen_channel - elapsed)) + u"s left)"
+        message += " (" + round(seconds_listen_channel - elapsed) + "s left)"
     return trim_leading_dashes(alert_title), trim_leading_dashes(message)
 
 
